@@ -1183,18 +1183,28 @@ char *DICOMImage::GetShadowSet()
 			return NULL;
 		}
 
-		char *strn = storage;
-  
 		// Find the beginning of what we're interested in
+		// Start from the back of the buffer and find matching
+		// "ASCCONV END"/"ASCCONV BEGIN" block
 		// Cannot use standard string search methods 'cause this is full of NULLs
 
-		U32 startp = 0;
-		while (startp < len)
+		U32 startp = len - 1;
+		char *strn = &(storage[startp]);
+  
+		while ( startp > 0 )
+		{
+			if ((*strn == '#') && (strncmp(strn, "### ASCCONV END ###", 18) == 0))
+				break;
+			--strn;
+			--startp;
+		}
+
+		while ( startp > 0 )
 		{
 			if ((*strn == '#') && (strncmp(strn, "### ASCCONV BEGIN ###", 21) == 0))
 				break;
-			++strn;
-			++startp;
+			--strn;
+			--startp;
 		}
 
 		len = len - startp + 1;
